summaryrefslogtreecommitdiffstats
path: root/src/autotraceformats.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 21:30:26 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 21:30:26 +0000
commit94ddde53d91cbdb554bbe78b108ccbd6a7d7c13a (patch)
tree961f7eb9997011a96d54a249dcb663025f686102 /src/autotraceformats.h
parentdad5420e97a9a56cce014e9380026063ee9d279c (diff)
downloadpotracegui-94ddde53d91cbdb554bbe78b108ccbd6a7d7c13a.tar.gz
potracegui-94ddde53d91cbdb554bbe78b108ccbd6a7d7c13a.zip
TQt4 port potracegui
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/potracegui@1239033 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/autotraceformats.h')
-rw-r--r--src/autotraceformats.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/src/autotraceformats.h b/src/autotraceformats.h
index 00359d8..aa00e9b 100644
--- a/src/autotraceformats.h
+++ b/src/autotraceformats.h
@@ -20,34 +20,35 @@
#ifndef AUTOTRACEFORMATS_H
#define AUTOTRACEFORMATS_H
-#include <qobject.h>
-#include <qstringlist.h>
-#include <qprocess.h>
+#include <tqobject.h>
+#include <tqstringlist.h>
+#include <tqprocess.h>
//! Class to read autotrace input and output formats
/** This class executes autotrace to gain informations about the formats it can use
* \author Antonio Fasolato
*/
-class AutotraceFormats : public QObject
+class AutotraceFormats : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- //! Standard QObject-like constructor
+ //! Standard TQObject-like constructor
/** The constructor, nothing fancy
* \param parent The parent of the QObject
* \param name The name of the QObject
*/
- AutotraceFormats(QObject *parent = 0, const char *name = 0);
+ AutotraceFormats(TQObject *tqparent = 0, const char *name = 0);
//!Returns the list of supported input formats
/** This class returns the list of formats returned by <code>autotrace -list-input-formats</code>
* \return The supported formats
*/
- QStringList inputFormats();
+ TQStringList inputFormats();
//!Returns the list of supported output formats
/** This class returns the list of formats returned by <code>autotrace -list-output-formats</code>
* \return The supported formats
*/
- QStringList outputFormats();
+ TQStringList outputFormats();
//! Function to test the execution of autotrace
/** This functions returns <code>true</code> if the autotrace command could be run succesfully. If it returns
* <code>false</code> autotrace executable can not be found in the environment
@@ -62,13 +63,13 @@ public:
private:
//! The process to get input formats
- QProcess *inputProcess;
+ TQProcess *inputProcess;
//! The process to get output formats
- QProcess *outputProcess;
+ TQProcess *outputProcess;
//! The list of input formats
- QStringList input;
+ TQStringList input;
//! The list of output formats
- QStringList output;
+ TQStringList output;
//! <code>true</code> if autotrace could be run
bool allOK;
@@ -20,34 +20,35 @@
/** The constructor, nothing fancy
- * \param parent The parent of the QObject
- * \param name The name of the QObject
+ * \param tqparent The tqparent of the TQObject
+ * \param name The name of the TQObject
*/